"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveFunctionAnnotation = void 0;
const errors_js_1 = require("../errors.js");
const fallback_js_1 = require("../functions/fallback.js");
const function_context_js_1 = require("./function-context.js");
const resolve_value_js_1 = require("./resolve-value.js");
function resolveFunctionAnnotation(ctx, operand, { name, options }) {
    let source;
    try {
        let fnInput;
        if (operand) {
            fnInput = [(0, resolve_value_js_1.resolveValue)(ctx, operand)];
            source = (0, resolve_value_js_1.getValueSource)(operand);
        }
        else {
            fnInput = [];
        }
        source ??= `:${name}`;
        const rf = ctx.functions[name];
        if (!rf) {
            throw new errors_js_1.MessageError('missing-func', `Unknown function ${name}`);
        }
        const msgCtx = new function_context_js_1.MessageFunctionContext(ctx, source);
        const opt = resolveOptions(ctx, options);
        return rf(msgCtx, opt, ...fnInput);
    }
    catch (error) {
        ctx.onError(error);
        source ??= (0, resolve_value_js_1.getValueSource)(operand) ?? `:${name}`;
        return (0, fallback_js_1.fallback)(source);
    }
}
exports.resolveFunctionAnnotation = resolveFunctionAnnotation;
function resolveOptions(ctx, options) {
    const opt = Object.create(null);
    if (options) {
        for (const { name, value } of options) {
            opt[name] = (0, resolve_value_js_1.resolveValue)(ctx, value);
        }
    }
    return opt;
}
