import { type MessageNode } from './data-model/types.js';
/**
 * Base error class used by MessageFormat
 *
 * @beta
 */
export declare class MessageError extends Error {
    type: 'missing-func' | 'not-formattable' | typeof MessageResolutionError.prototype.type | typeof MessageSelectionError.prototype.type | typeof MessageSyntaxError.prototype.type;
    constructor(type: typeof MessageError.prototype.type, message: string);
}
/**
 * Errors in the message syntax.
 *
 * @beta
 */
export declare class MessageSyntaxError extends MessageError {
    type: 'empty-token' | 'bad-escape' | 'bad-input-expression' | 'bad-selector' | 'duplicate-declaration' | 'duplicate-option' | 'extra-content' | 'key-mismatch' | 'parse-error' | 'missing-fallback' | 'missing-selector-annotation' | 'missing-syntax';
    start: number;
    end: number;
    constructor(type: typeof MessageSyntaxError.prototype.type, start: number, end?: number, expected?: string);
}
/**
 * Errors in the message data model.
 *
 * @beta
 */
export declare class MessageDataModelError extends MessageSyntaxError {
    type: 'duplicate-declaration' | 'duplicate-option' | 'key-mismatch' | 'missing-fallback' | 'missing-selector-annotation';
    constructor(type: typeof MessageDataModelError.prototype.type, node: MessageNode);
}
/**
 * Message runtime resolution errors
 *
 * @beta
 */
export declare class MessageResolutionError extends MessageError {
    type: 'bad-input' | 'bad-option' | 'unresolved-var' | 'unsupported-annotation' | 'unsupported-statement';
    source: string;
    constructor(type: typeof MessageResolutionError.prototype.type, message: string, source: string);
}
/**
 * Errors in message selection.
 *
 * @beta
 */
export declare class MessageSelectionError extends MessageError {
    type: 'no-match' | 'not-selectable';
    constructor(type: typeof MessageSelectionError.prototype.type);
}
