"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageSelectionError = exports.MessageResolutionError = exports.MessageDataModelError = exports.MessageSyntaxError = exports.MessageError = void 0;
const from_cst_js_1 = require("./data-model/from-cst.js");
/**
 * Base error class used by MessageFormat
 *
 * @beta
 */
class MessageError extends Error {
    type;
    constructor(type, message) {
        super(message);
        this.type = type;
    }
}
exports.MessageError = MessageError;
/**
 * Errors in the message syntax.
 *
 * @beta
 */
class MessageSyntaxError extends MessageError {
    start;
    end;
    constructor(type, start, end, expected) {
        let message = expected ? `Missing ${expected}` : type;
        if (start >= 0)
            message += ` at ${start}`;
        super(type, message);
        this.start = start;
        this.end = end ?? start + 1;
    }
}
exports.MessageSyntaxError = MessageSyntaxError;
/**
 * Errors in the message data model.
 *
 * @beta
 */
class MessageDataModelError extends MessageSyntaxError {
    constructor(type, node) {
        const { start, end } = node[from_cst_js_1.cst] ?? { start: -1, end: -1 };
        super(type, start, end);
    }
}
exports.MessageDataModelError = MessageDataModelError;
/**
 * Message runtime resolution errors
 *
 * @beta
 */
class MessageResolutionError extends MessageError {
    source;
    constructor(type, message, source) {
        super(type, message);
        this.source = source;
    }
}
exports.MessageResolutionError = MessageResolutionError;
/**
 * Errors in message selection.
 *
 * @beta
 */
class MessageSelectionError extends MessageError {
    constructor(type) {
        super(type, `Selection error: ${type}`);
    }
}
exports.MessageSelectionError = MessageSelectionError;
