import type { MessageExpressionPart } from '../formatted-parts.js';
import type { MessageFunctionContext, MessageValue } from './index.js';
/** @beta */
export interface MessageDateTime extends MessageValue {
    readonly type: 'datetime';
    readonly source: string;
    readonly locale: string;
    readonly options: Readonly<Intl.DateTimeFormatOptions>;
    toParts(): [MessageDateTimePart];
    toString(): string;
    valueOf(): Date;
}
/** @beta */
export interface MessageDateTimePart extends MessageExpressionPart {
    type: 'datetime';
    source: string;
    locale: string;
    parts: Intl.DateTimeFormatPart[];
}
/**
 * `datetime` accepts a Date, number or string as its input
 * and formats it with the same options as
 * {@link https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/DateTimeFormat | Intl.DateTimeFormat}.
 *
 * @beta
 */
export declare const datetime: (ctx: MessageFunctionContext, options: Record<string, unknown>, input?: unknown) => MessageDateTime;
/**
 * `date` accepts a Date, number or string as its input
 * and formats it according to a single "style" option.
 *
 * @beta
 */
export declare const date: (ctx: MessageFunctionContext, options: Record<string, unknown>, input?: unknown) => MessageDateTime;
/**
 * `time` accepts a Date, number or string as its input
 * and formats it according to a single "style" option.
 *
 * @beta
 */
export declare const time: (ctx: MessageFunctionContext, options: Record<string, unknown>, input?: unknown) => MessageDateTime;
