import type { MessageExpressionPart } from '../formatted-parts.js';
import type { MessageFunctionContext, MessageValue } from './index.js';
/** @beta */
export interface MessageNumber extends MessageValue {
    readonly type: 'number';
    readonly source: string;
    readonly locale: string;
    readonly options: Readonly<Intl.NumberFormatOptions & Intl.PluralRulesOptions>;
    /**
     * In addition to matching exact values,
     * numerical values may also match keys with the same plural rule category,
     * i.e. one of `zero`, `one`, `two`, `few`, `many`, and `other`.
     *
     * @remarks
     * Different languages use different subset of plural rule categories.
     * For example, cardinal English plurals only use `one` and `other`,
     * so a key `zero` will never be matched for that locale.
     */
    selectKey(keys: Set<string>): string | null;
    toParts?: () => [MessageNumberPart];
    toString?: () => string;
    valueOf(): number | bigint;
}
/** @beta */
export interface MessageNumberPart extends MessageExpressionPart {
    type: 'number';
    source: string;
    locale: string;
    parts: Intl.NumberFormatPart[];
}
/**
 * `number` accepts a number, BigInt or string representing a JSON number as input
 * and formats it with the same options as
 * {@link https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/NumberFormat | Intl.NumberFormat}.
 * It also supports plural category selection via
 * {@link https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/PluralRules | Intl.PluralRules}.
 *
 * @beta
 */
export declare function number({ localeMatcher, locales, source }: MessageFunctionContext, options: Record<string | symbol, unknown>, input?: unknown): MessageNumber;
/**
 * `integer` accepts a number, BigInt or string representing a JSON number as input
 * and formats it with the same options as
 * {@link https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/NumberFormat | Intl.NumberFormat}.
 * It also supports plural category selection via
 * {@link https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl/PluralRules | Intl.PluralRules}.
 *
 * The `maximumFractionDigits=0` and `style='decimal'` options are fixed for `:integer`.
 *
 * @beta
 */
export declare const integer: (ctx: MessageFunctionContext, options: Record<string, unknown>, input?: unknown) => MessageNumber;
