import type { MessageFunctionContext } from './data-model/function-context.js';
import type { Message } from './data-model/types.js';
import type { MessagePart } from './formatted-parts.js';
import { MessageValue } from './functions/index.js';
/**
 * The runtime function registry available when resolving {@link FunctionAnnotation} elements.
 *
 * @beta
 */
export interface MessageFunctions {
    [key: string]: (context: MessageFunctionContext, options: Record<string, unknown>, input?: unknown) => MessageValue;
}
/** @beta */
export interface MessageFormatOptions {
    /**
     * If given multiple locales,
     * determines which algorithm to use when selecting between them;
     * the default for `Intl` formatters is `'best fit'`.
     *
     * @remarks
     * See: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Intl#locale_negotiation
     */
    localeMatcher?: 'best fit' | 'lookup';
    /**
     * The set of custom functions available during message resolution.
     * Extends the default set of functions.
     */
    functions?: MessageFunctions;
}
/**
 * Create a new message formatter.
 *
 * @beta
 */
export declare class MessageFormat {
    #private;
    constructor(source: string | Message, locales?: string | string[], options?: MessageFormatOptions);
    format(msgParams?: Record<string, unknown>, onError?: (error: unknown) => void): string;
    formatToParts(msgParams?: Record<string, unknown>, onError?: (error: unknown) => void): MessagePart[];
    resolvedOptions(): {
        functions: Readonly<Readonly<MessageFunctions>>;
        localeMatcher: "lookup" | "best fit";
        locales: string[];
        message: Readonly<Message>;
    };
    private createContext;
}
